@@ -76,6 +76,10 @@
 #'   sum_by = "clnt"
 #' )
 compute_comorbidity <- function(data, vars, icd_ver = c("ICD-10", "ICD-9-CM-3digits", "ICD-9-CM-5digits"), clnt_id, uid = NULL, sum_by = c("row", "clnt"), excl = NULL) {
+  if(!is.data.frame(data)) {
+    check_con(data)
+  }
+
   # input check
   icd_ver <- rlang::arg_match(icd_ver)
   sum_by <- rlang::arg_match(sum_by)
